@@ -21,7 +21,7 @@ def subparser(subparsers):
 
 def configure(args):
     """Configure GQRX"""
-    info = config.read_cfg_file(args.cfg_file, args.cfg_dir)
+    info = config.read_cfg_file(args.cfg, args.cfg_dir)
 
     if (info is None):
         return
