@@ -2,14 +2,13 @@
 from argparse import ArgumentDefaultsHelpFormatter
 from . import config, defs, util
 import subprocess, logging, textwrap, os
+from shutil import which
 logger = logging.getLogger(__name__)
 
 
 def _tune_max_pipe_size(pipesize):
     """Tune the maximum size of pipes"""
-    try:
-        subprocess.check_output(["which", "sysctl"])
-    except subprocess.CalledProcessError:
+    if (not which("sysctl")):
         logging.error("Couldn't tune max-pipe-size. Please check how to tune "
                       "it in your OS.")
         return False
@@ -37,29 +36,18 @@ def _tune_max_pipe_size(pipesize):
         return True
 
 
-def _check_apps(tsp_disabled, bindir):
+def _check_apps(tsp_disabled):
     """Check if required apps are installed"""
-    try:
-        subprocess.check_output(["which", "rtl_sdr"])
-    except subprocess.CalledProcessError:
-        logging.error("Couldn't find rtl_sdr. Is it installed?")
-        return False
 
-    if (not os.path.isfile(os.path.join(bindir, "leandvb"))):
-        logging.error("Couldn't find leandvb. Is it installed?")
-        return False
-
-    if (not os.path.isfile(os.path.join(bindir, "ldpc_tool"))):
-        logging.error("Couldn't find ldpc_tool. Is it installed?")
-        return False
-
-    if (tsp_disabled):
-        return True
-
-    if (not os.path.isfile(os.path.join(bindir, "tsp"))):
-        logging.error("Couldn't find tsp. Is it installed?")
-        return False
+    apps      = ["rtl_sdr", "leandvb", "ldpc_tool", "tsp"]
 
+    for app in apps:
+        if (app == "tsp" and tsp_disabled):
+            continue
+        if (not which(app)):
+            logging.error("Couldn't find {}. Is it installed?".format(app))
+            return False
+    # All apps are installed
     return True
 
 
@@ -164,18 +152,17 @@ def subparser(subparsers):
 
 
 def run(args):
-    info = config.read_cfg_file(args.cfg_file, args.cfg_dir)
+    info = config.read_cfg_file(args.cfg, args.cfg_dir)
 
     if (info is None):
         return
 
-    bindir = os.path.join(args.cfg_dir, "usr", "bin")
-
     pipe_size_bytes = int(args.pipe_size * (2**20))
     if (not _tune_max_pipe_size(pipe_size_bytes)):
         return
 
-    if (not _check_apps((args.no_tsp or args.record), bindir)):
+    tsp_unused = args.no_tsp or args.record
+    if (not _check_apps(tsp_unused)):
         print("\nTo install software dependencies, run:")
         print("""
         blocksat-cli deps install
@@ -219,8 +206,7 @@ def run(args):
         else:
             rtl_cmd.append("-")
 
-    ldvb_path = os.path.join(bindir, "leandvb")
-    ldvb_cmd  = [ldvb_path, "--nhelpers", str(args.n_helpers), "-f",
+    ldvb_cmd  = ["leandvb", "--nhelpers", str(args.n_helpers), "-f",
                 str(samp_rate), "--sr", str(sym_rate), "--roll-off",
                 str(defs.rolloff), "--standard", "DVB-S2", "--sampler", "rrc",
                 "--rrc-rej", str(args.rrc_rej), "--modcods", modcod,
@@ -231,8 +217,7 @@ def run(args):
     elif (args.debug_ts > 1):
         ldvb_cmd.extend(["-d", "-d"])
     if (args.ldpc_dec == "ext"):
-        ldpc_tool_path = os.path.join(bindir, "ldpc_tool")
-        ldvb_cmd.extend(["--ldpc-helper", ldpc_tool_path,
+        ldvb_cmd.extend(["--ldpc-helper", which("ldpc_tool"),
                          "--ldpc-iterations", str(args.ldpc_iterations)])
     else:
         ldvb_cmd.extend(["--ldpc-bf", str(args.ldpc_bf)])
@@ -248,8 +233,7 @@ def run(args):
     ldvb_stderr = None if (args.debug_ts > 0) else subprocess.DEVNULL
 
     # Input
-    tsp_path = os.path.join(bindir, "tsp")
-    tsp_cmd  = [tsp_path, "--realtime", "--buffer-size-mb",
+    tsp_cmd  = ["tsp", "--realtime", "--buffer-size-mb",
                 str(args.buffer_size_mb), "--max-flushed-packets",
                 str(args.max_flushed_packets), "--max-input-packets",
                 str(args.max_input_packets)]
