@@ -5,7 +5,6 @@ import os, sys, signal, argparse, subprocess, time, logging, threading, json
 from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
 from . import config, util, defs, rp, firewall, ip
 import textwrap
-from shutil import which
 logger = logging.getLogger(__name__)
 
 
@@ -452,11 +451,6 @@ def subparser(subparsers):
                                   description="Launch a USB DVB-S2 receiver",
                                   help='Launch a Linux USB DVB-S2 receiver')
 
-    p1.add_argument('-c', '--chan-conf',
-                    default="channels.conf",
-                    help='Channel configurations file within the configuration \
-                    directory')
-
     p1.add_argument('-l', '--lnb',
                     choices=defs.lnb_options,
                     default=None,
@@ -541,7 +535,7 @@ def subparser(subparsers):
 
 def _common(args):
     # User info
-    user_info = config.read_cfg_file(args.cfg_file, args.cfg_dir)
+    user_info = config.read_cfg_file(args.cfg, args.cfg_dir)
 
     if (user_info is None):
         return
@@ -623,7 +617,7 @@ def launch(args):
     user_info, adapter, frontend = common_params
 
     # Channel configuration file
-    chan_conf = os.path.join(args.cfg_dir, os.path.basename(args.chan_conf))
+    chan_conf = user_info['setup']['channel']
 
     # Zap
     zap_ps = zap(adapter, frontend, chan_conf, user_info, lnb=args.lnb,
